#!/usr/bin/env python
# -*- coding: utf-8 -*-

""" Check if pickle can serialize seabird's data objects

"""

import os
from glob import glob
import pickle

import numpy as np

from seabird import cnv


def test_serialize_CNV():
        """ Serialize CNV
        """
        datadir = os.path.join(os.path.dirname(__file__), 'test_data')
        for f in glob(os.path.join(datadir, "*.cnv.OK")):
            profile = cnv.CNV(open(f).read())
            profile2 = pickle.loads(pickle.dumps(profile))
            assert profile.attributes == profile2.attributes
            assert (profile.data == profile.data)


def test_serialize_fCNV():
        """ Serialize fCNV
        """
        datadir = os.path.join(os.path.dirname(__file__), 'test_data')
        for f in glob(os.path.join(datadir, "*.cnv.OK")):
            profile = cnv.fCNV(f)
            profile2 = pickle.loads(pickle.dumps(profile))
            assert profile.attributes == profile2.attributes
            assert (profile.data == profile.data)



import os
import re
import logging


def make_file_list(inputdir, inputpattern=".*\.cnv"):
    """ Search inputdir recursively for inputpattern
    """
    inputfiles = []
    for dirpath, dirnames, filenames in os.walk(inputdir):
        for filename in filenames:
            if re.match(inputpattern, filename):
                inputfiles.append(os.path.join(dirpath,filename))
    inputfiles.sort()
    return inputfiles

def basic_logger(logger=None):
    if logger is not None:
        assert type(logger) is logging.Logger
    else:
        # create logger
        logger = logging.getLogger('CNV logger')
        logger.setLevel(logging.DEBUG)

        # create console handler and set level to debug
        ch = logging.StreamHandler()
        ch.setLevel(logging.DEBUG)

        # create formatter
        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')

        # add formatter to ch
        ch.setFormatter(formatter)

        # add ch to logger
        logger.addHandler(ch)

    return logger





""" Parse some references with fCNV

"""

import os
from glob import glob

from seabird import cnv

def test_answer():
        """ Load different .cnv versions with fCNV
        """
        datadir = os.path.join(os.path.dirname(__file__), 'test_data')
        for f in glob(os.path.join(datadir, "*.cnv.OK")):
            print("Loading file: %s" % f)
            profile = cnv.fCNV(f)



#!/usr/bin/env python
# -*- coding: utf-8 -*-


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read().replace('.. :changelog:', '')

version = '0.6.1'

install_requires = [
    'numpy>=1.1',
    'PyYAML',
]

test_requirements = [
]

setup(
    name='seabird',
    version=version,
    description="Non official parser for Sea-Bird's sensors.",
    long_description=readme + '\n\n' + history,
    author='Guilherme Castelao , Luiz Irber',
    author_email='guilherme@castelao.net, luiz.irber@gmail.com',
    url='http://seabird.castelao.net',
    packages=[
        'seabird',
    ],
    package_dir={'seabird':
                 'seabird'},
    include_package_data=True,
    install_requires=install_requires,
    license='PSF',
    zip_safe=False,
    keywords='oceanography ocean data CTD SeaBird hydrography parser',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: Python Software Foundation License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Scientific/Engineering',
    ],
    download_url='https://pypi.python.org/packages/source/s/seabird/seabird-'+version+'.tar.gz',
    entry_points={
        'console_scripts':
            ['seabird=seabird:main']
    },
    platforms='any',
    scripts=["bin/cnvdump", "bin/cnv2nc"],
    test_suite='tests',
    tests_require=test_requirements
)



""" Check the rules
"""

import os
import pkg_resources
import re
import yaml
import seabird

def load_rules():
    """ Try to read all rules with yaml

        https://github.com/castelao/seabird/issues/7
    """
    rules_dir = 'rules'
    rule_files = pkg_resources.resource_listdir(seabird.__name__, rules_dir)
    rule_files = [f for f in rule_files if re.match('^cnv.*yaml$', f)]
    for rule_file in rule_files:
        print("loading rule: %s", (rule_file))
        text = pkg_resources.resource_string(seabird.__name__,
                os.path.join(rules_dir, rule_file))
        rule = yaml.load(text)
        assert type(rule) == dict
        assert len(rule.keys()) > 0

def test_answer():
    assert load_rules() == None
